Content — TreeTime User Manual 2025.4 documentation

TreeTime is a general data organisation, management and analysis tool using linked trees instead of flat lists of tables. A tree is a hierarchical structure that arranges your data into units and sub-units. Mathematical functions (sum, difference, mean, ratio) can be calculated recursively. Linked trees are distinct trees that share data between them. In TreeTime, a data object is part of several trees at the same time.

# Content

- Introduction
  - Concept
  - Basic Use
  - Data Files
  - Installation
- Meta Structure
  - Principles
  - Trees and the Data Item
  - Data Fields
  - Tree Fields
  - Recursion
  - Input/Output Types
- Data Format
  - Global Structure
  - Tree Definition
  - Data Item Definition
  - The Data Pool
- Data Fields
  - string
  - text
  - longtext
  - url
  - integer
  - timer
- Tree Fields
  - General Syntax
  - Hidden Fields
  - string
  - url
  - text
  - sum
  - set
  - sum-time
  - difference
  - difference-time
  - mean
  - mean-percent
  - min
  - max
  - min-string
  - max-string
  - product
  - reciprocal
  - ratio
  - ratio-percent
  - node-name
  - node-path
- History and Road Map
  - Past
  - Present
  - Future

- Index

- Module Index

- Search Page